@@ -2,8 +2,7 @@
 
 from invenio_records_permissions.generators import AnyUser
 
-from invenio_drafts_resources.services.records.permissions import \
-    RecordPermissionPolicy
+from invenio_drafts_resources.services.records.permissions import RecordPermissionPolicy
 
 
 class PermissionPolicy(RecordPermissionPolicy):
@@ -12,6 +11,7 @@ class PermissionPolicy(RecordPermissionPolicy):
     can_edit = [AnyUser()]
     can_new_version = [AnyUser()]
     can_search = [AnyUser()]
+    can_search_drafts = [AnyUser()]
     can_create = [AnyUser()]
     can_read = [AnyUser()]
     can_read_draft = [AnyUser()]
